==> hqsoft_core-0.0.20.tar.gz: lib/core_base/widgets/calculator.dart <==
import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/value_base.dart';

class Calculator {
  List<String> data = [
    '7',
    '8',
    '9',
    '4',
    '5',
    '6',
    '1',
    '2',
    '3',
    '.',
    '0',
    'del',
    'C'
  ];
  String value = '0';
  final ValueNotifier<String> _valueDisplay = ValueNotifier('0');
  final ButtonCallBack onClickButton;

  Calculator({this.onClickButton});

  Future<void> showCalculatorDialog(BuildContext context, String title) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: Container(
            height: 400, //ScreenConfig.safeBlockVertical * 60,
            child: Column(
              children: <Widget>[
                Container(
                  height: 50,
                  width: 200,
                  padding: const EdgeInsets.symmetric(horizontal: 8),
                  alignment: FractionalOffset.centerRight,
                  decoration: BoxDecoration(
                    color: Colors.lightBlue,
                    //border: Border.all(color: Colors.grey, width: 0.4),
                    borderRadius: BorderRadius.all(Radius.circular(8.0)),
                  ),
                  child: ValueListenableBuilder(
                      valueListenable: _valueDisplay,
                      builder: (context, value, _) {
                        return Text(
                          '$value',
                          textAlign: TextAlign.right,
                          style: TextStyle(
                              fontSize: 20,
                              fontWeight: FontWeight.bold,
                              color: Colors.white),
                        );
                      }),
                ),
                Container(
                  margin: const EdgeInsets.fromLTRB(0, 8, 0, 0),
                  width: 200,
                  height: 340,
                  child: new GridView.builder(
                      itemCount: data.length,
                      gridDelegate:
                          new SliverGridDelegateWithFixedCrossAxisCount(
                              crossAxisCount: 3),
                      itemBuilder: (BuildContext context, int index) {
                        return InkWell(
                          onTap: () {
                            if (data[index] == 'del') {
                              value = value.substring(0, value.length - 1);
                            } else if (data[index] == 'C') {
                              value = '0';
                            } else {
                              value = (value == '0' ? '' : value) + data[index];
                            }
                            print(value);
                            _valueDisplay.value =
                                value.length == 0 ? '0' : value;
                          },
                          child: Container(
                            child: new Card(
                              child: Center(
                                child: data[index] == 'del'
                                    ? Icon(Icons.backspace)
                                    : Text(
                                        data[index],
                                        style: TextStyle(
                                            fontSize: 20,
                                            fontWeight: FontWeight.bold),
                                      ),
                              ),
                            ),
                          ),
                        );
                      }),
                )
              ],
            ),
          ),
          actions: <Widget>[
            FlatButton(
              child: Text(
                'Cancel',
                style: TextStyle(color: Colors.grey),
              ),
              onPressed: () {
                value = '0';
                _valueDisplay.value = '0';
                onClickButton(double.parse(_valueDisplay.value));
                Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL);
              },
            ),
            FlatButton(
              child: Text('OK', style: TextStyle(color: colorPrimary)),
              onPressed: () {
                onClickButton(double.parse(_valueDisplay.value));
                value = '0';
                _valueDisplay.value = '0';

                Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT);
              },
            ),
          ],
        );
      },
    );
  }
}

typedef ButtonCallBack = void Function(double qty);

==> hqsoft_core-0.0.63.tar.gz: lib/core_base/widgets/calculator.dart <==
import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/value_base.dart';

class Calculator {
  List<String> data = [
    '7',
    '8',
    '9',
    '4',
    '5',
    '6',
    '1',
    '2',
    '3',
    '.',
    '0',
    'del',
    'C'
  ];
  String value = '0';
  final ValueNotifier<String> _valueDisplay = ValueNotifier('0');
  final ButtonCallBack onClickButton;

  Calculator({required this.onClickButton});

  Future<void> showCalculatorDialog(BuildContext context, String title) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: Container(
            height: 400, //ScreenConfig.safeBlockVertical * 60,
            child: Column(
              children: <Widget>[
                Container(
                  height: 50,
                  width: 200,
                  padding: const EdgeInsets.symmetric(horizontal: 8),
                  alignment: FractionalOffset.centerRight,
                  decoration: BoxDecoration(
                    color: Colors.lightBlue,
                    //border: Border.all(color: Colors.grey, width: 0.4),
                    borderRadius: BorderRadius.all(Radius.circular(8.0)),
                  ),
                  child: ValueListenableBuilder(
                      valueListenable: _valueDisplay,
                      builder: (context, value, _) {
                        return Text(
                          '$value',
                          textAlign: TextAlign.right,
                          style: TextStyle(
                              fontSize: 20,
                              fontWeight: FontWeight.bold,
                              color: Colors.white),
                        );
                      }),
                ),
                Container(
                  margin: const EdgeInsets.fromLTRB(0, 8, 0, 0),
                  width: 200,
                  height: 340,
                  child: new GridView.builder(
                      itemCount: data.length,
                      gridDelegate:
                          new SliverGridDelegateWithFixedCrossAxisCount(
                              crossAxisCount: 3),
                      itemBuilder: (BuildContext context, int index) {
                        return InkWell(
                          onTap: () {
                            if (data[index] == 'del') {
                              value = value.substring(0, value.length - 1);
                            } else if (data[index] == 'C') {
                              value = '0';
                            } else {
                              value = (value == '0' ? '' : value) + data[index];
                            }
                            print(value);
                            _valueDisplay.value =
                                value.length == 0 ? '0' : value;
                          },
                          child: Container(
                            child: new Card(
                              child: Center(
                                child: data[index] == 'del'
                                    ? Icon(Icons.backspace)
                                    : Text(
                                        data[index],
                                        style: TextStyle(
                                            fontSize: 20,
                                            fontWeight: FontWeight.bold),
                                      ),
                              ),
                            ),
                          ),
                        );
                      }),
                )
              ],
            ),
          ),
          actions: <Widget>[
            FlatButton(
              child: Text(
                'Cancel',
                style: TextStyle(color: Colors.grey),
              ),
              onPressed: () {
                value = '0';
                _valueDisplay.value = '0';
                onClickButton(double.parse(_valueDisplay.value));
                Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL);
              },
            ),
            FlatButton(
              child: Text('OK', style: TextStyle(color: colorPrimary)),
              onPressed: () {
                onClickButton(double.parse(_valueDisplay.value));
                value = '0';
                _valueDisplay.value = '0';

                Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT);
              },
            ),
          ],
        );
      },
    );
  }
}

typedef ButtonCallBack = void Function(double qty);
